@@ -14,10 +14,15 @@
 
 #include "PackageModel.h"
 
-#include <QObject>
-#include <QUrl>
+#include "locale/TranslatableConfiguration.h"
+#include "modulesystem/InstanceKey.h"
 
-class QNetworkReply;
+#include <QObject>
+#include <QVariantMap>
+
+#include <memory>
+
+class LoaderQueue;
 
 class Config : public QObject
 {
@@ -26,17 +31,25 @@ class Config : public QObject
     Q_PROPERTY( PackageModel* packageModel MEMBER m_model FINAL )
     Q_PROPERTY( QString status READ status NOTIFY statusChanged FINAL )
 
+    // Translations, of the module name (for sidebar) and above the list
+    Q_PROPERTY( QString sidebarLabel READ sidebarLabel NOTIFY sidebarLabelChanged FINAL )
+    Q_PROPERTY( QString titleLabel READ titleLabel NOTIFY titleLabelChanged FINAL )
+
 public:
     Config( QObject* parent = nullptr );
     ~Config() override;
 
+    void setConfigurationMap( const QVariantMap& configurationMap );
+
     enum class Status
     {
         Ok,
         FailedBadConfiguration,
         FailedInternalError,
         FailedNetworkError,
-        FailedBadData
+        FailedBadData,
+        FailedNoData
+
     };
 
     QString status() const;
@@ -45,12 +58,10 @@ public:
     bool required() const { return m_required; }
     void setRequired( bool r ) { m_required = r; }
 
-    /** @brief Retrieves the groups, with name, description and packages
-     *
-     * Loads data from the given URL. Once done, the data is parsed
-     * and passed on to the other loadGroupList() method.
-     */
-    void loadGroupList( const QUrl& url );
+    PackageModel* model() const { return m_model; }
+
+    QString sidebarLabel() const;
+    QString titleLabel() const;
 
     /** @brief Fill model from parsed data.
      *
@@ -59,18 +70,28 @@ public:
      */
     void loadGroupList( const QVariantList& groupData );
 
-    PackageModel* model() const { return m_model; }
+    /** @brief Write the selected package lists to global storage
+     *
+     * Since the config doesn't know what module it is for,
+     * pass in an instance key.
+     */
+    void finalizeGlobalStorage( const Calamares::ModuleSystem::InstanceKey& key );
 
-signals:
+Q_SIGNALS:
     void statusChanged( QString status );  ///< Something changed
+    void sidebarLabelChanged( QString label );
+    void titleLabelChanged( QString label );
     void statusReady();  ///< Loading groups is complete
 
-private slots:
-    void receivedGroupData();  ///< From async-loading group data
+private Q_SLOTS:
+    void retranslate();
+    void loadingDone();
 
 private:
+    CalamaresUtils::Locale::TranslatedString* m_sidebarLabel = nullptr;  // As it appears in the sidebar
+    CalamaresUtils::Locale::TranslatedString* m_titleLabel = nullptr;
     PackageModel* m_model = nullptr;
-    QNetworkReply* m_reply = nullptr;  // For fetching data
+    LoaderQueue* m_queue = nullptr;
     Status m_status = Status::Ok;
     bool m_required = false;
 };
