@@ -119,7 +119,7 @@ ChoicePage::ChoicePage( Config* config, QWidget* parent )
     // Drive selector + preview
     CALAMARES_RETRANSLATE( retranslateUi( this ); m_drivesLabel->setText( tr( "Select storage de&vice:" ) );
                            m_previewBeforeLabel->setText( tr( "Current:" ) );
-                           m_previewAfterLabel->setText( tr( "After:" ) ); )
+                           m_previewAfterLabel->setText( tr( "After:" ) ); );
 
     m_previewBeforeFrame->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Expanding );
     m_previewAfterFrame->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Expanding );
@@ -298,7 +298,7 @@ ChoicePage::setupChoices()
 
     CALAMARES_RETRANSLATE( m_somethingElseButton->setText( tr( "<strong>Manual partitioning</strong><br/>"
                                                                "You can create or resize partitions yourself." ) );
-                           updateSwapChoicesTr( m_eraseSwapChoiceComboBox ); )
+                           updateSwapChoicesTr( m_eraseSwapChoiceComboBox ); );
 }
 
 
@@ -1303,7 +1303,7 @@ ChoicePage::setupActions()
 
             m_replaceButton->setText( tr( "<strong>Replace a partition</strong><br/>"
                                           "Replaces a partition with %1." )
-                                          .arg( Calamares::Branding::instance()->shortVersionedName() ) ); )
+                                          .arg( Calamares::Branding::instance()->shortVersionedName() ) ); );
 
         m_replaceButton->hide();
         m_alongsideButton->hide();
@@ -1337,7 +1337,7 @@ ChoicePage::setupActions()
 
                 m_replaceButton->setText( tr( "<strong>Replace a partition</strong><br/>"
                                               "Replaces a partition with %1." )
-                                              .arg( Calamares::Branding::instance()->shortVersionedName() ) ); )
+                                              .arg( Calamares::Branding::instance()->shortVersionedName() ) ); );
         }
         else
         {
@@ -1358,7 +1358,7 @@ ChoicePage::setupActions()
 
                 m_replaceButton->setText( tr( "<strong>Replace a partition</strong><br/>"
                                               "Replaces a partition with %1." )
-                                              .arg( Calamares::Branding::instance()->shortVersionedName() ) ); )
+                                              .arg( Calamares::Branding::instance()->shortVersionedName() ) ); );
         }
     }
     else
@@ -1383,7 +1383,7 @@ ChoicePage::setupActions()
 
             m_replaceButton->setText( tr( "<strong>Replace a partition</strong><br/>"
                                           "Replaces a partition with %1." )
-                                          .arg( Calamares::Branding::instance()->shortVersionedName() ) ); )
+                                          .arg( Calamares::Branding::instance()->shortVersionedName() ) ); );
     }
 
 #ifdef DEBUG_PARTITION_UNSAFE
