@@ -34,7 +34,8 @@ CheckerContainer::CheckerContainer( const Calamares::RequirementsModel& model, Q
     CalamaresUtils::unmarginLayout( mainLayout );
 
     mainLayout->addWidget( m_waitingWidget );
-    CALAMARES_RETRANSLATE( if ( m_waitingWidget ) m_waitingWidget->setText( tr( "Gathering system information..." ) ); )
+    CALAMARES_RETRANSLATE( if ( m_waitingWidget )
+                               m_waitingWidget->setText( tr( "Gathering system information..." ) ); );
 }
 
 CheckerContainer::~CheckerContainer()
